@@ -30,7 +30,7 @@ class ContainerSpec(DockerCamelModel):
     labels: Optional[Dict[str, str]]
     privileges: Optional[Dict[str, Optional[str]]]
     stop_grace_period: Optional[int]
-    isolation: str
+    isolation: Optional[str]
     env: Optional[List[str]]
 
 
@@ -42,14 +42,14 @@ class TaskTemplate(DockerCamelModel):
 class ChangeConfig(DockerCamelModel):
     parallelism: int
     failure_action: str
-    monitor: int
-    max_failure_ratio: int
-    order: str
+    monitor: Optional[int]
+    max_failure_ratio: Optional[int]
+    order: Optional[str]
 
 
 class ServiceSpec(DockerCamelModel):
     name: str
-    labels: Dict[str, str]
+    labels: Optional[Dict[str, str]]
     mode: Optional[Dict[str, Any]]
     update_config: Optional[ChangeConfig]
     rollback_config: Optional[ChangeConfig]
@@ -64,8 +64,8 @@ class EndpointPortConfig(DockerCamelModel):
     name: Optional[str]
     protocol: str
     target_port: int
-    published_port: int
-    publish_mode: str
+    published_port: Optional[int]
+    publish_mode: Optional[str]
 
 
 class ServiceEndpointSpec(DockerCamelModel):
